@@ -403,6 +403,10 @@ public:
                                      bool invalidateTimeline = false, bool revertMove = false);
     Q_INVOKABLE bool requestSubtitleMove(int clipId, int position, bool updateView = true, bool logUndo = true, bool finalMove = false);
     bool requestSubtitleMove(int clipId, int position, bool updateView, bool first, bool last, bool finalMove, Fun &undo, Fun &redo);
+    /** @brief return the previous blank frame on a track */
+    Q_INVOKABLE int getPreviousBlank(int trackId, int pos);
+    /** @brief return the next blank frame on a track */
+    Q_INVOKABLE int getNextBlank(int trackId, int pos);
     int cutSubtitle(int position, Fun &undo, Fun &redo);
     bool requestClipMix(const QString &mixId, std::pair<int, int> clipIds, std::pair<int, int> mixDurations, int trackId, int position, bool updateView,
                         bool invalidateTimeline, bool finalMove, Fun &undo, Fun &redo, bool groupMove);
@@ -700,12 +704,18 @@ protected:
 
     /** @brief Returns the best possible size for a clip on resize
      */
-    int requestItemResizeInfo(int itemId, int in, int out, int size, bool right, int snapDistance);
+    int requestItemResizeInfo(int itemId, int currentIn, int currentOut, int requestedSize, bool right, int snapDistance);
 
     /** @brief Returns a list of in/out of all items in the group of itemId
      */
     const std::vector<int> getBoundaries(int itemId);
 
+    /** @brief Extract selection from its group. To be used when operating on single items in a group
+     *  @returns a pair with { original group id of the element, the id of the other element
+     *  in the group if it was a 2 items group and group was deleted in the operation }
+     */
+    std::pair<int, int> extractSelectionFromGroup(std::unordered_set<int> selection, Fun &undo, Fun &redo);
+
 public:
     /** @brief Requests the next snapped point
        @param pos is the current position
